@@ -230,7 +230,7 @@
            Lambda.ineq.constraints){
 
     Lambda <- matrix(0, K, factors)
-    if (is.na(lambda.start)){# sets Lambda to equality constraints & 0s
+    if (any(is.na(lambda.start))){# sets Lambda to equality constraints & 0s
       for (i in 1:K){
         for (j in 1:factors){
           if (Lambda.eq.constraints[i,j]==-999){
@@ -413,7 +413,7 @@
   function(psi.start, X){
     
     K <- ncol(X)
-    if (is.na(psi.start)){
+    if (any(is.na(psi.start))){
       Psi <- 0.5 * diag(diag(var(X)))
     }
     else if (is.double(psi.start) &&
@@ -663,7 +663,7 @@
            stop("Please respecify and call ", calling.function(), " again.",
                 call.=FALSE)          
          }
-         if( all(lec.seed[1:3]) == 0 ){
+         if( all(lec.seed[1:3] == 0 )){
            cat("Error: first three L'Ecuyer seeds == 0\n")
            stop("Please respecify and call ", calling.function(), " again.",
                 call.=FALSE)          
@@ -674,7 +674,7 @@
            stop("Please respecify and call ", calling.function(), " again.",
                 call.=FALSE)          
          }         
-         if( all(lec.seed[4:6]) == 0 ){
+         if( all(lec.seed[4:6] == 0 )){
            cat("Error: last three L'Ecuyer seeds == 0\n")
            stop("Please respecify and call ", calling.function(), " again.",
                 call.=FALSE)          
